summaryrefslogtreecommitdiffstats
path: root/cmakemodules
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-11-16 13:38:23 -0600
committerTimothy Pearson <[email protected]>2011-11-16 13:38:23 -0600
commit07b42c91aa4a6363714fd194817d1be6466675bf (patch)
tree2880c0a8d5fea362270c6fbda0cb6a857a9d5dad /cmakemodules
parentfd9dca56be44910dfff4b1a174fdaa1a40ce1683 (diff)
downloadkbfx-07b42c91aa4a6363714fd194817d1be6466675bf.tar.gz
kbfx-07b42c91aa4a6363714fd194817d1be6466675bf.zip
Additional renaming of kde to tde
Diffstat (limited to 'cmakemodules')
-rw-r--r--cmakemodules/FindKDE4Internal.cmake14
-rw-r--r--cmakemodules/FindKDEWIN32.cmake10
-rw-r--r--cmakemodules/FindKdeLibs.cmake2
3 files changed, 13 insertions, 13 deletions
diff --git a/cmakemodules/FindKdeLibs.cmake b/cmakemodules/FindKdeLibs.cmake
index 356c0e4..d6761b3 100644
--- a/cmakemodules/FindKdeLibs.cmake
+++ b/cmakemodules/FindKdeLibs.cmake
@@ -299,7 +299,7 @@ ENDIF (NOT KDE3_FIND_QUIETLY)
#add the found Qt and KDE include directories to the current include path
SET(KDE3_INCLUDE_DIRS ${QT_INCLUDE_DIR} ${KDE3_INCLUDE_DIR})
-include(kdesvnMacros)
+include(tdesvnMacros)
IF(CMAKE_SIZEOF_VOID_P EQUAL 4)
SET(DEF_SUFF "")
diff --git a/cmakemodules/FindKDE4Internal.cmake b/cmakemodules/FindKDE4Internal.cmake
index d96433f..fad8dc2 100644
--- a/cmakemodules/FindKDE4Internal.cmake
+++ b/cmakemodules/FindKDE4Internal.cmake
@@ -321,11 +321,11 @@ option(KDE4_ENABLE_FPIE "Enable platform supports PIE linking")
#now try to find some kde stuff
#are we trying to compile kdelibs ?
#then enter bootstrap mode
if(EXISTS ${CMAKE_SOURCE_DIR}/tdecore/kernel/kglobal.h)
- message(STATUS "Building kdelibs...")
+ message(STATUS "Building tdelibs...")
set(KDE4_INCLUDE_DIR ${CMAKE_SOURCE_DIR})
set(KDE4_TDECORE_LIBS ${QT_QTCORE_LIBRARY} tdecore)
@@ -353,7 +353,7 @@ if(EXISTS ${CMAKE_SOURCE_DIR}/tdecore/kernel/kglobal.h)
set(KDE4_LIB_DIR ${LIBRARY_OUTPUT_PATH}/${CMAKE_CFG_INTDIR})
# when building kdelibs, make the kcfg rules depend on the binaries...
set( _KDE4_KCONFIG_COMPILER_DEP kconfig_compiler)
set( _KDE4_MAKEKDEWIDGETS_DEP makekdewidgets)
set( _KDE4_MEINPROC_EXECUTABLE_DEP meinproc)
@@ -391,7 +391,7 @@ else(EXISTS ${CMAKE_SOURCE_DIR}/tdecore/kernel/kglobal.h)
set(LIBRARY_OUTPUT_PATH ${CMAKE_BINARY_DIR}/lib )
# this file contains all dependencies of all libraries of kdelibs, Alex
include(${kde_cmake_module_dir}/KDELibsDependencies.cmake)
find_library(KDE4_TDECORE_LIBRARY NAMES tdecore PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
@@ -541,7 +541,7 @@ if (WIN32)
set( _KDE4_PLATFORM_INCLUDE_DIRS ${KDEWIN32_INCLUDES} ${GNUWIN32_INCLUDE_DIR})
- # if we are compiling kdelibs, add KDEWIN32_LIBRARIES explicitely,
+ # if we are compiling tdelibs, add KDEWIN32_LIBRARIES explicitely,
# otherwise they come from KDELibsDependencies.cmake, Alex
if(EXISTS ${CMAKE_SOURCE_DIR}/tdecore/kernel/kglobal.h)
set( KDE4_TDECORE_LIBS ${KDE4_TDECORE_LIBS} ${KDEWIN32_LIBRARIES} )
@@ -785,7 +785,7 @@ endif (KDE4_INCLUDE_DIR AND KDE4_LIB_DIR AND KDE4_KCFGC_EXECUTABLE AND KDE4_INST
macro (KDE4_PRINT_RESULTS)
# inside kdelibs the include dir and lib dir are internal, not "found"
if(NOT EXISTS ${CMAKE_SOURCE_DIR}/tdecore/kernel/kglobal.h)
if(KDE4_INCLUDE_DIR)
message(STATUS "Found KDE4 include dir: ${KDE4_INCLUDE_DIR}")
@@ -812,7 +812,7 @@ if (KDE4Internal_FIND_REQUIRED AND NOT KDE4_FOUND)
#bail out if something wasn't found
kde4_print_results()
if (NOT KDE4_INSTALLED_VERSION_OK)
- message(FATAL_ERROR "ERROR: the installed kdelibs version ${KDEVERSION} is too old, at least version ${KDE_MIN_VERSION} is required")
+ message(FATAL_ERROR "ERROR: the installed tdelibs version ${KDEVERSION} is too old, at least version ${KDE_MIN_VERSION} is required")
else (NOT KDE4_INSTALLED_VERSION_OK)
message(FATAL_ERROR "ERROR: could NOT find everything required for compiling KDE 4 programs")
endif (NOT KDE4_INSTALLED_VERSION_OK)
@@ -321,11 +321,11 @@ option(KDE4_ENABLE_FPIE "Enable platform supports PIE linking")
#now try to find some kde stuff
-#are we trying to compile kdelibs ?
+#are we trying to compile tdelibs ?
#then enter bootstrap mode
if(EXISTS ${CMAKE_SOURCE_DIR}/tdecore/kernel/kglobal.h)
@@ -353,7 +353,7 @@ if(EXISTS ${CMAKE_SOURCE_DIR}/tdecore/kernel/kglobal.h)
set(KDE4_LIB_DIR ${LIBRARY_OUTPUT_PATH}/${CMAKE_CFG_INTDIR})
- # when building kdelibs, make the kcfg rules depend on the binaries...
+ # when building tdelibs, make the kcfg rules depend on the binaries...
set( _KDE4_KCONFIG_COMPILER_DEP kconfig_compiler)
set( _KDE4_MAKEKDEWIDGETS_DEP makekdewidgets)
@@ -391,7 +391,7 @@ else(EXISTS ${CMAKE_SOURCE_DIR}/tdecore/kernel/kglobal.h)
set(LIBRARY_OUTPUT_PATH ${CMAKE_BINARY_DIR}/lib )
- # this file contains all dependencies of all libraries of kdelibs, Alex
+ # this file contains all dependencies of all libraries of tdelibs, Alex
include(${kde_cmake_module_dir}/KDELibsDependencies.cmake)
find_library(KDE4_TDECORE_LIBRARY NAMES tdecore PATHS ${KDE4_LIB_INSTALL_DIR} NO_DEFAULT_PATH )
@@ -785,7 +785,7 @@ endif (KDE4_INCLUDE_DIR AND KDE4_LIB_DIR AND KDE4_KCFGC_EXECUTABLE AND KDE4_INST
macro (KDE4_PRINT_RESULTS)
- # inside kdelibs the include dir and lib dir are internal, not "found"
+ # inside tdelibs the include dir and lib dir are internal, not "found"
if(NOT EXISTS ${CMAKE_SOURCE_DIR}/tdecore/kernel/kglobal.h)
if(KDE4_INCLUDE_DIR)
diff --git a/cmakemodules/FindKDEWIN32.cmake b/cmakemodules/FindKDEWIN32.cmake
index afa8ee9..37470be 100644
--- a/cmakemodules/FindKDEWIN32.cmake
+++ b/cmakemodules/FindKDEWIN32.cmake
@@ -24,7 +24,7 @@ find_path(KDEWIN32_INCLUDE_DIR winposix_export.h
)
# at first find the kdewin32 library, this has to be compiled and installed before kdelibs/
# search for kdewin32 in the default install directory for applications (default of (n)make install)
set(KDEWIN32_LIBRARY_PATH ${_program_FILES_DIR}/kdewin32/lib)
@@ -42,7 +42,7 @@ if(MSVC)
if(MSVC_IDE)
# the ide needs the debug and release version
if( NOT KDEWIN32_LIBRARY_DEBUG OR NOT KDEWIN32_LIBRARY_RELEASE)
- message(FATAL_ERROR "\nCould NOT find the debug AND release version of the KDEWIN32 library.\nYou need to have both to use MSVC projects.\nPlease build and install both kdelibs/win/ libraries first.\n")
+ message(FATAL_ERROR "\nCould NOT find the debug AND release version of the KDEWIN32 library.\nYou need to have both to use MSVC projects.\nPlease build and install both tdelibs/win/ libraries first.\n")
endif( NOT KDEWIN32_LIBRARY_DEBUG OR NOT KDEWIN32_LIBRARY_RELEASE)
SET(KDEWIN32_LIBRARY optimized ${KDEWIN32_LIBRARY_RELEASE} debug ${KDEWIN32_LIBRARY_DEBUG})
else(MSVC_IDE)
@@ -57,8 +57,8 @@ else(MSVC)
set(KDEWIN32_LIBRARY ${KDEWIN32_LIBRARY_RELEASE})
endif(MSVC)
# kdelibs/win/ has to be built before the rest of kdelibs/
# eventually it will be moved out from kdelibs/
if (KDEWIN32_LIBRARY AND KDEWIN32_INCLUDE_DIR)
set(KDEWIN32_FOUND TRUE)
# add needed system libs
@@ -82,7 +82,7 @@ if (KDEWIN32_FOUND)
endif (NOT KDEWIN32_FIND_QUIETLY)
else (KDEWIN32_FOUND)
if (KDEWIN32_FIND_REQUIRED)
- message(FATAL_ERROR "Could NOT find KDEWIN32 library\nPlease build and install kdelibs/win/ first")
+ message(FATAL_ERROR "Could NOT find KDEWIN32 library\nPlease build and install tdelibs/win/ first")
endif (KDEWIN32_FIND_REQUIRED)
endif (KDEWIN32_FOUND)
@@ -24,7 +24,7 @@ find_path(KDEWIN32_INCLUDE_DIR winposix_export.h
)
-# at first find the kdewin32 library, this has to be compiled and installed before kdelibs/
+# at first find the kdewin32 library, this has to be compiled and installed before tdelibs/
# search for kdewin32 in the default install directory for applications (default of (n)make install)
set(KDEWIN32_LIBRARY_PATH ${_program_FILES_DIR}/kdewin32/lib)
@@ -57,8 +57,8 @@ else(MSVC)
set(KDEWIN32_LIBRARY ${KDEWIN32_LIBRARY_RELEASE})
endif(MSVC)
-# kdelibs/win/ has to be built before the rest of kdelibs/
-# eventually it will be moved out from kdelibs/
+# tdelibs/win/ has to be built before the rest of tdelibs/
+# eventually it will be moved out from tdelibs/
if (KDEWIN32_LIBRARY AND KDEWIN32_INCLUDE_DIR)
set(KDEWIN32_FOUND TRUE)